/* Copyright (C) 2000-2003 Markus Lausser (sgop@users.sf.net)
   This is free software distributed under the terms of the
   GNU Public License.  See the file COPYING for details. */

void string_list_clear(int lists);
char *string_list_search(int slist, char *item);
GtkCList *string_list_get_clist(int slist);
GtkEntry *string_list_get_entry(int slist);
void string_list_add(int slist, char *item);
void string_list_remove(int slist, char *item);

void highlight_add(char *item);
void highlight_remove(char *item);
void friend_add(char *item);
void friend_remove(char *item);
void enemy_add(char *item);
void enemy_remove(char *item);
void ignore_add(char *item);
void ignore_remove(char *item);
void banreason_add(char *item);
void banreason_remove(char *item);
void nodownload_add(char *item);
void nodownload_remove(char *item);
void afkreason_add(char *item);
void afkreason_remove(char *item);
void qsearch_add(char *item);
void qsearch_remove(char *item);

GtkWidget *create_string_list_popup(int slist);
